@@ -64,7 +64,7 @@ class PipeFollower(threading.Thread):
             ".".join([self.__class__.__name__, name, pname])
         )
         self.pipe_logger = types.MethodType(
-            pipe_logger_factory(), self, PipeFollower
+            pipe_logger_factory(), self
         )
 
     def run(self):
